__author__ = 'PointCode Organization'
__doc__ = """
HtmlLib is a free python package, using to discribe html page with Python.
It is built by PointCode Organization and released on the platform of Python.
We highly recommended it to you because of 3 advantages:
1. The project is made of python, which means light, reliable and Cross-Platform.
2. Compared with others packages, it is much simpler in frame and easier to use.
3. It is useful and international to control html web.
"""